#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_with	tests	# unit tests (few failures as of 5.0.0)
%bcond_without	python2 # CPython 2.x module
%bcond_with	python3 # CPython 3.x module (built from python3-rdflib.spec)
%bcond_with	tools	# package tools (built from python3-rdflib.spec)

%define	module	rdflib

Summary:	Python 2 library for working with RDF
Summary(pl.UTF-8):	Biblioteka Pythona 2 do pracy z RDF
Name:		python-%{module}
# keep 5.x here for python2 support
Version:	5.0.0
Release:	1
License:	BSD
Group:		Libraries/Python
#Source0Download: https://github.com/RDFLib/rdflib/releases
Source0:	https://github.com/RDFLib/rdflib/archive/%{version}/%{module}-%{version}.tar.gz
# Source0-md5:	aaca854daef803da19010181eb99e3e1
URL:		https://rdflib.dev/
%if %{with python2}
BuildRequires:	python-modules >= 1:2.7
BuildRequires:	python-setuptools
%if %{with tests}
BuildRequires:	python-doctest-ignore-unicode
BuildRequires:	python-html5lib
BuildRequires:	python-isodate
BuildRequires:	python-networkx
BuildRequires:	python-nose
BuildRequires:	python-pyparsing
BuildRequires:	python-six
%endif
%endif
%if %{with python3}
BuildRequires:	python3-modules >= 1:3.4
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-doctest-ignore-unicode
BuildRequires:	python3-html5lib
BuildRequires:	python3-isodate
BuildRequires:	python3-networkx
BuildRequires:	python3-nose
BuildRequires:	python3-pyparsing
BuildRequires:	python3-six
%endif
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	python3-sphinxcontrib-apidoc
BuildRequires:	sphinx-pdg >= 2.4
%endif
Requires:	python-modules >= 1:2.7
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
RDFLib is a Python library for working with RDF, a simple yet powerful
language for representing information. The library contains an RDF/XML
parser/serializer, a TripleStore, an InformationStore and various
store backends. It is being developed by Daniel Krech along with the
help of a number of contributors.

%description -l pl.UTF-8
RDFLib to biblioteka Pythona do pracy z RDF - prostym, ale potężnym
językiem do reprezentowania informacji. Biblioteka zawiera
parser/serializer RDF/XML, TripleStore, InformationStore oraz różne
backendy do przechowywania informacji. Jest rozwijana przez Daniela
Krecha z pomocą wielu współpracowników.

%package -n python3-%{module}
Summary:	Python 3 library for working with RDF
Summary(pl.UTF-8):	Biblioteka Pythona 3 do pracy z RDF
Group:		Libraries/Python
Requires:	python3-modules >= 1:3.4

%description -n python3-%{module}
RDFLib is a Python library for working with RDF, a simple yet powerful
language for representing information. The library contains an RDF/XML
parser/serializer, a TripleStore, an InformationStore and various
store backends. It is being developed by Daniel Krech along with the
help of a number of contributors.

%description -n python3-%{module} -l pl.UTF-8
RDFLib to biblioteka Pythona do pracy z RDF - prostym, ale potężnym
językiem do reprezentowania informacji. Biblioteka zawiera
parser/serializer RDF/XML, TripleStore, InformationStore oraz różne
backendy do przechowywania informacji. Jest rozwijana przez Daniela
Krecha z pomocą wielu współpracowników.

%package apidocs
Summary:	API documentation for Python rdflib module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona rdflib
Group:		Documentation

%description apidocs
API documentation for Python rdflib module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona rdflib.

%package -n rdflib-tools
Summary:	Utilities from python-rdflib
Summary(pl.UTF-8):	Narzędzia z pakietu python-rdflib
Group:		Applications/File
%if %{with python3}
Requires:	python3-%{module} = %{version}-%{release}
%else
Requires:	%{name} = %{version}-%{release}
%endif

%description -n rdflib-tools
Utilities from python-rdflib.

%description -n rdflib-tools -l pl.UTF-8
Narzędzia z pakietu python-rdflib.

%prep
%setup -q -n %{module}-%{version}

%build
%if %{with python2}
%py_build %{?with_tests:test}
%endif

%if %{with python3}
%py3_build %{?with_tests:test}
%endif

%if %{with doc}
%{__make} -C docs html
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean

%if %{with python3} || %{without tools}
%{__rm} $RPM_BUILD_ROOT%{_bindir}/*
%endif

install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -p examples/*.py $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python3}
%py3_install

install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
cp -p examples/*.py $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}

%if %{without tools}
%{__rm} $RPM_BUILD_ROOT%{_bindir}/*
%endif
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc CHANGELOG.md CONTRIBUTORS LICENSE README.md
%{py_sitescriptdir}/rdflib
%{py_sitescriptdir}/rdflib-%{version}-py*.egg-info
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc CHANGELOG.md CONTRIBUTORS LICENSE README.md
%{py3_sitescriptdir}/rdflib
%{py3_sitescriptdir}/rdflib-%{version}-py*.egg-info
%{_examplesdir}/python3-%{module}-%{version}
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_images,_modules,_static,apidocs,*.html,*.js}
%endif

%if %{with tools}
%files -n rdflib-tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/csv2rdf
%attr(755,root,root) %{_bindir}/rdf2dot
%attr(755,root,root) %{_bindir}/rdfgraphisomorphism
%attr(755,root,root) %{_bindir}/rdfpipe
%attr(755,root,root) %{_bindir}/rdfs2dot
%endif
%changelog
* Sun Apr 03 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-rdflib.git;a=log;h=master

* Sun Apr 03 2022 Jakub Bogusz <qboosh@pld-linux.org> 7c37552
- updated python versions, disable python3 here

* Sun Apr 03 2022 Jakub Bogusz <qboosh@pld-linux.org> cd166f0
- updated to 5.0.0; added apidocs and optional tests

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> ecbc7eb
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 00a88f4
- Release 6 (by relup.sh)

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 5a765ab
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 32f8bec
- rebuild with python 3.10

* Fri Feb 26 2021 Jan Rękorajski <baggins@pld-linux.org> 705fc3c
- release 3 (by relup.sh)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> b12df4d
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> b390c5f
- up to 4.2.2

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 1706a3e
- release 3 (by relup.sh)

* Thu Dec 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 665af3b
- python 3.6
- release 2 (by relup.sh)

* Sun Dec 04 2016 Jakub Bogusz <qboosh@pld-linux.org> 8b40fbd
- pl for rdflib-tools, examples to _examplesdir

* Sat Nov 19 2016 Jacek Konieczny <jajcus@jajcus.net> 5052334
- Version: 4.2.1, python3 support

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 0b9d45e
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> a0e9b7d
- release 3 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> f634e65
- automatic change: use py_build/py_install macros

* Thu Jan 26 2012 lisu <lisu@pld-linux.org> 61d5dd4
- R: python-isodate
- rel 2

* Sun Jan 22 2012 zbyniu <zbyniu@pld-linux.org> e033727
- up to 3.2.0

* Sun Mar 20 2011 Marcin Banasiak <marcin.banasiak@gmail.com> 285e18c
- updated to 3.0.0

* Sun Jan 23 2011 sparky <sparky@pld-linux.org> c100659
- added BR: python-modules, rpm-pythonprov

